@@ -1,12 +1,14 @@
 package Class::groups ;
-$VERSION = 1.79 ;
+$VERSION = 2.1 ;
+use 5.006_001 ;
+use strict ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
 
-; use 5.006_001
-; use base 'Class::props'
-; use strict
+; use Class::props
+; our @ISA = qw| Class::props |
+
 ; use Carp
 ; $Carp::Internal{+__PACKAGE__}++
 
@@ -120,9 +122,7 @@ $VERSION = 1.79 ;
                        }
                     }
                  }
-              ; wantarray
-                ? keys %$hash
-                : $hash
+              ; wantarray ? %$hash : $hash  # no argument
               }
          }
       }
@@ -134,13 +134,15 @@ $VERSION = 1.79 ;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Class::groups - Pragma to implement group of properties
 
-=head1 VERSION 1.79
+=head1 VERSION 2.1
 
-Included in OOTools 1.79 distribution.
+Included in OOTools 2.1 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -160,6 +162,10 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
+=item * Class::Error
+
+Delayed checking of object failure
+
 =item * Object::props
 
 Pragma to implement lvalue accessors with options
@@ -168,6 +174,10 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
+=item * Class::Util
+
+Class utility functions
+
 =back
 
 =head1 INSTALLATION
@@ -246,18 +256,21 @@ From the directory where this file is located, type:
     
     # adding an unknow property (see no_strict)
     MyClass->myOtherGroup(prop5 => 5) ;
+    
+    # copying the whole hash
+    %myGroupHash = MyClass->myGroup
 
 =head1 WARNING
 
-Don't use the group accessor in list context in order to retrieve the hash keys. It is deprecated and it will return the whole hash in a future version.
+Don't use the group accessor in list context in order to retrieve the hash keys: that way was deprecated and it doesn't work any more with this version.
 
-    # deprecated
+    # WRONG
     @keys     = MyClass->myGroup ;
     
     # change it with
     @keys     = keys %{MyClass->myGroup} ;
     
-    # future behaviour in list context
+    # new behaviour in list context
     %hash = MyClass->myGroup ;
 
 =head1 DESCRIPTION
@@ -308,8 +321,6 @@ If you want to see some working example of this module, take a look at the sourc
 
 =head1 OPTIONS
 
-=over
-
 =head2 name => $name
 
 The name of the group accessor.
@@ -377,4 +388,5 @@ All Rights Reserved. This module is free software. It may be used, redistributed
 
 Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
 
+=cut
 
