@@ -1,19 +1,24 @@
 package Object::groups ;
-$VERSION = 1.79 ;
+$VERSION = 2.1 ;
+use 5.006_001 ;
+use strict ;
 
-use base 'Class::groups' ;
+; use Class::groups
+; our @ISA = qw| Class::groups |
    
-1 ;
+; 1
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Object::groups - Pragma to implement group of properties
 
-=head1 VERSION 1.79
+=head1 VERSION 2.1
 
-Included in OOTools 1.79 distribution.
+Included in OOTools 2.1 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -33,6 +38,10 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
+=item * Class::Error
+
+Delayed checking of object failure
+
 =item * Object::props
 
 Pragma to implement lvalue accessors with options
@@ -41,6 +50,10 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
+=item * Class::Util
+
+Class utility functions
+
 =back
 
 =head1 INSTALLATION
@@ -124,19 +137,22 @@ From the directory where this file is located, type:
        
     # adding an unknow property (see no_strict)
     $object->myOtherGroup(prop5 => 5) ;
+    
+    # copying the whole hash
+    %myGroupHash = $object->myGroup
 
 =head1 WARNING
 
-Don't use the group accessor in list context in order to retrieve the hash keys. It is deprecated and it will return the whole hash in a future version.
+Don't use the group accessor in list context in order to retrieve the hash keys: that way was deprecated and it doesn't work any more with this version.
 
-    # deprecated
-    @keys     = $object->myGroup ;
+    # WRONG
+    @keys     = MyClass->myGroup ;
     
     # change it with
-    @keys     = keys %{$object->myGroup} ;
+    @keys     = keys %{MyClass->myGroup} ;
     
-    # future behaviour in list context
-    %hash = $object->myGroup ;
+    # new behaviour in list context
+    %hash = MyClass->myGroup ;
 
 =head1 DESCRIPTION
 
@@ -253,3 +269,5 @@ All Rights Reserved. This module is free software. It may be used, redistributed
 =head1 CREDITS
 
 Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
+
+=cut
