@@ -1,19 +1,24 @@
 package Object::props ;
-$VERSION = 1.79 ;
+$VERSION = 2.1 ;
+use 5.006_001 ;
+use strict ;
 
-use base 'Class::props' ;
-
-1 ;
+; use Class::props
+; our @ISA = qw| Class::props |
+   
+; 1
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Object::props - Pragma to implement lvalue accessors with options
 
-=head1 VERSION 1.79
+=head1 VERSION 2.1
 
-Included in OOTools 1.79 distribution.
+Included in OOTools 2.1 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -33,6 +38,10 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
+=item * Class::Error
+
+Delayed checking of object failure
+
 =item * Object::props
 
 Pragma to implement lvalue accessors with options
@@ -41,6 +50,10 @@ Pragma to implement lvalue accessors with options
 
 Pragma to implement groups of properties accessors with options
 
+=item * Class::Util
+
+Class utility functions
+
 =back
 
 =head1 INSTALLATION
@@ -297,3 +310,5 @@ All Rights Reserved. This module is free software. It may be used, redistributed
 =head1 CREDITS
 
 Thanks to Juerd Waalboer (http://search.cpan.org/author/JUERD) that with its I<Attribute::Property> inspired the creation of this distribution.
+
+=cut
